@@ -25,6 +25,13 @@ test_that("test get_tournaments for proper outputs", {
   testthat::skip_if_offline()
   testthat::skip_on_cran()
 
+  df <- get_tournaments(year = 2021, world_tour = FALSE)
+  expect_is(df, "data.frame")
+  expect_is(df, "tbl")
+  expect_equal(length(unique(df$category)), 2)
+  expect_is(sample(df$date, 1), "Date")
+  expect_equal(year(sample(df$date, 1)), 2021)
+
   df <- get_tournaments(year = 2020, world_tour = TRUE)
   expect_is(df, "data.frame")
   expect_is(df, "tbl")
@@ -32,11 +39,4 @@ test_that("test get_tournaments for proper outputs", {
   expect_is(sample(df$date, 1), "Date")
   expect_equal(year(sample(df$date, 1)), 2020)
 
-  df <- get_tournaments(year = 2019, world_tour = TRUE)
-  expect_is(df, "data.frame")
-  expect_is(df, "tbl")
-  expect_equal(length(unique(df$category)), 2)
-  expect_is(sample(df$date, 1), "Date")
-  expect_equal(year(sample(df$date, 1)), 2019)
-
 })
